@@ -13,25 +13,26 @@
 #include "bamtools_tool.h"
 
 namespace BamTools {
-  
-class SortTool : public AbstractTool {
-  
-    public:
-        SortTool(void);
-        ~SortTool(void);
-  
-    public:
-        int Help(void);
-        int Run(int argc, char* argv[]); 
-        
-    private:
-        struct SortSettings;
-        SortSettings* m_settings;
-        
-        class SortToolPrivate;
-        SortToolPrivate* m_impl;
-};
-  
-} // namespace BamTools
 
-#endif // BAMTOOLS_SORT_H
+class SortTool : public AbstractTool
+{
+
+public:
+    SortTool();
+    ~SortTool();
+
+public:
+    int Help();
+    int Run(int argc, char* argv[]);
+
+private:
+    struct SortSettings;
+    SortSettings* m_settings;
+
+    class SortToolPrivate;
+    SortToolPrivate* m_impl;
+};
+
+}  // namespace BamTools
+
+#endif  // BAMTOOLS_SORT_H
